==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/tsenable.php <==
<?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

//require("guiconfig.inc");
//Load pfsense modules
require("filter.inc");
require("shaper.inc");
require_once("config.gui.inc");

// Make ThreatSTOP rules
$rule = array(
        'type' => 'pass',
        'interface' => 'lan',
        'statetype' => 'keep state',
        'source' => array(
                'any' => true
        ),
        'destination' => array(
                'address' => 'ThreatSTOP_allow'
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_lan'
);

$rule2 = array(
        'type' => 'block',
        'interface' => 'lan',
        'statetype' => 'keep state',
        'source' => array(
                'any' => true
        ),
        'destination' => array(
                'address' => 'ThreatSTOP_block'
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_lan'
);
//If gateway mode

$rule4 = array(
        'type' => 'pass',
        'interface' => 'wan',
        'statetype' => 'keep state',
        'source' => array(
                'address' => 'ThreatSTOP_allow'
        ),
        'destination' => array(
                'any' => true
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_wan'
);
$rule5 = array(
        'type' => 'block',
        'interface' => 'wan',
        'statetype' => 'keep state',
        'source' => array(
                'address' => 'ThreatSTOP_block'
        ),
        'destination' => array(
                'any' => true
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_wan'
);
//Make ThreatSTOP aliase. This files consit block and allow ThreatSTOP address
$alias = array(
        'name'=>'ThreatSTOP_allow',
        'url'=>'http://ThreatSTOP_allow.local',
        'updatefreq'=>'7',
        'address'=>'',
        'descr'=>'',
        'type'=>'urltable',
        'detail'=>'',
      );
$alias2 = array(
        'name'=>'ThreatSTOP_block',
        'url'=>'http://ThreatSTOP_block.local',
        'updatefreq'=>'7',
        'address'=>'',
        'descr'=>'',
        'type'=>'urltable',
        'detail'=>'',
      );



global $config;
array_unshift($config['filter']['rule'], $rule, $rule2, $rule4, $rule5);
$config['aliases']['alias'][] = $alias;
$config['aliases']['alias'][] = $alias2;

//store previous noantilockout state, and then turn it on 
if(isset($config['system']['webgui']['noantilockout'])) {
    $config['threatstop']['noantilockout'] = true;
} else {
    $config['threatstop']['noantilockout'] = false;
}

$config['system']['webgui']['noantilockout']=true;



write_config('qqq');
filter_configure();
sleep(2);
header("Location: /ts_state.php");
shell_exec('rm  /tmp/config.cache');
//add ThreatStop lists
//include 'tsgetblockip.php';

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/tsenable.php <==
<?php
/**
 *
 * Copyright(c) 2006-2018 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

//Load pfsense modules
require("guiconfig.inc");
require_once("functions.inc");
require("filter.inc");
require("shaper.inc");
require_once("config.gui.inc");

// Make ThreatSTOP rules
$rule = array(
        'type' => 'pass',
        'interface' => 'lan',
        'statetype' => 'keep state',
        'source' => array(
                'any' => true
        ),
        'destination' => array(
                'address' => 'ThreatSTOP_allow'
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_lan'
);

$rule2 = array(
        'type' => 'block',
        'interface' => 'lan',
        'statetype' => 'keep state',
        'source' => array(
                'any' => true
        ),
        'destination' => array(
                'address' => 'ThreatSTOP_block'
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_lan'
);
//If gateway mode

$rule4 = array(
        'type' => 'pass',
        'interface' => 'wan',
        'statetype' => 'keep state',
        'source' => array(
                'address' => 'ThreatSTOP_allow'
        ),
        'destination' => array(
                'any' => true
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_wan'
);
$rule5 = array(
        'type' => 'block',
        'interface' => 'wan',
        'statetype' => 'keep state',
        'source' => array(
                'address' => 'ThreatSTOP_block'
        ),
        'destination' => array(
                'any' => true
        ),
        'log' => true,
        'descr' => 'ThreatSTOP_incoming_wan'
);
//Make ThreatSTOP aliase. This files consit block and allow ThreatSTOP address
$alias = array(
        'name'=>'ThreatSTOP_allow',
        'url'=>'http://ThreatSTOP_allow.local',
        'updatefreq'=>'7',
        'address'=>'',
        'descr'=>'',
        'type'=>'urltable',
        'detail'=>'',
      );
$alias2 = array(
        'name'=>'ThreatSTOP_block',
        'url'=>'http://ThreatSTOP_block.local',
        'updatefreq'=>'7',
        'address'=>'',
        'descr'=>'',
        'type'=>'urltable',
        'detail'=>'',
      );



global $config;
array_unshift($config['filter']['rule'], $rule, $rule2, $rule4, $rule5);
$config['aliases']['alias'][] = $alias;
$config['aliases']['alias'][] = $alias2;

//store previous noantilockout state, and then turn it on 
if(isset($config['system']['webgui']['noantilockout'])) {
    $config['threatstop']['noantilockout'] = true;
} else {
    $config['threatstop']['noantilockout'] = false;
}

$config['system']['webgui']['noantilockout']=true;



write_config('qqq');
filter_configure();
sleep(2);
header("Location: /ts_state.php");
shell_exec('rm  /tmp/config.cache');
//add ThreatStop lists
//include 'tsgetblockip.php';
